declare

Function declare 

pub fn declare(
    types: &Types,
    names: &Interner,
    id: TypeId,
    name: Symbol,
) -> String
The type as a declaration of name, which is how it would be written in the program.