pub struct Alias {
pub name: Symbol,
pub of: TypeId,
}Expand description
A typedef name the program wrote, and what it stands for.
Fields
name: SymbolThe name.
of: TypeIdThe type it was written for, which is the same type the name resolves to rather than a type of its own.