pub struct Spelled {
pub record: RecordId,
pub member: Symbol,
pub name: Symbol,
pub of: TypeId,
}Expand description
A record member written with a typedef name, and the name it was written with.
Fields
record: RecordIdThe record the member is in.
member: SymbolThe member.
name: SymbolThe typedef name its specifiers named.
of: TypeIdThe type the name stood for, which the member’s type is built on top of.