pub struct TypeId(/* private fields */);Expand description
The identity of a type.
Four bytes, Copy, and equal exactly when the two types are the same type. Ids from two
different Types tables are not comparable, which is not a restriction in practice
because there is one table per translation unit.