pub fn compatible(types: &Types, left: TypeId, right: TypeId) -> boolExpand description
Whether a declaration of left and a declaration of right declare the same thing, 6.2.7.
Identity implies compatibility and is one integer comparison, so this only does any work when the two ids differ.